==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-attachments/dictionaries/fr.dict.itop-attachments.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', [
	'Attachment:Max_Go' => '(Taille de fichier max.: %1$s Gb)',
	'Attachment:Max_Ko' => '(Taille de fichier max.: %1$s Kb)',
	'Attachment:Max_Mo' => '(Taille de fichier max.: %1$s Mb)',
	'Attachments:AddAttachment' => 'Ajouter une pièce jointe: ',
	'Attachments:DeleteBtn' => 'Supprimer',
	'Attachments:EmptyTabTitle' => 'Pièces jointes',
	'Attachments:Error:FileTooLarge' => 'Le fichier est trop gros pour être chargé. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Le fichier téléchargé est vide et ne peut pas être attaché.
Soit vous avez attaché un fichier vide,
Soit demandez à votre administrateur système s\'il reste de la place disque disponible sur le serveur',
	'Attachments:FieldsetTitle' => 'Pièces jointes',
	'Attachments:File:Date' => 'Date de chargement',
	'Attachments:File:DownloadsCount' => 'Téléchargements',
	'Attachments:File:MimeType' => 'Type',
	'Attachments:File:Name' => 'Nom du fichier',
	'Attachments:File:Size' => 'Taille',
	'Attachments:File:Thumbnail' => 'Icône',
	'Attachments:File:Uploader' => 'Chargé par',
	'Attachments:History_File_Added' => 'Ajout de la pièce jointe: %1$s.',
	'Attachments:History_File_Removed' => 'Suppression de la pièce jointe: %1$s.',
	'Attachments:NoAttachment' => 'Aucune pièce jointe.',
	'Attachments:PreviewNotAvailable' => 'Pas d\'aperçu pour ce type de pièce jointe.',
	'Attachments:Render:Icons' => 'Affichage en icônes',
	'Attachments:Render:Table' => 'Affichage en liste',
	'Attachments:TabTitle_Count' => 'Pièces jointes (%1$d)',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Le téléchargement de fichiers est interdit sur ce système.',
	'Class:Attachment' => 'Attachement',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Contact',
	'Class:Attachment/Attribute:contact_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Contenu',
	'Class:Attachment/Attribute:contents+' => '',
	'Class:Attachment/Attribute:creation_date' => 'Date de création',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:expire' => 'Expire',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:item_class' => 'Classe d\'Item',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organisation de l\'Item',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id Temporaire',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:user_id' => 'Utilisateur',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:TriggerOnAttachmentDownload' => 'Déclencheur sur le téléchargement d\'une pièce jointe d\'un objet',
	'Class:TriggerOnAttachmentDownload+' => '',
	'UI:Attachments:DropYourFileHint' => 'Déposez vos fichiers dans cet espace',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-attachments/dictionaries/fr.dict.itop-attachments.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', array(
	'Attachments:TabTitle_Count' => 'Pièces jointes (%1$d)',
	'Attachments:EmptyTabTitle' => 'Pièces jointes',
	'Attachments:FieldsetTitle' => 'Pièces jointes',
	'Attachments:DeleteBtn' => 'Supprimer',
	'Attachments:History_File_Added' => 'Ajout de la pièce jointe: %1$s.',
	'Attachments:History_File_Removed' => 'Suppression de la pièce jointe: %1$s.',
	'Attachments:AddAttachment' => 'Ajouter une pièce jointe: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Le téléchargement de fichiers est interdit sur ce système.',
	'Attachment:Max_Go' => '(Taille de fichier max.: %1$s Gb)',
	'Attachment:Max_Mo' => '(Taille de fichier max.: %1$s Mb)',
	'Attachment:Max_Ko' => '(Taille de fichier max.: %1$s Kb)',
	'Attachments:NoAttachment' => 'Aucune pièce jointe.',
	'Attachments:PreviewNotAvailable' => 'Pas d\'aperçu pour ce type de pièce jointe.',
	'Attachments:Error:FileTooLarge' => 'Le fichier est trop gros pour être chargé. %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Le fichier téléchargé est vide et ne peut pas être attaché.
Soit vous avez attaché un fichier vide,
Soit demandez à votre administrateur système s\'il reste de la place disque disponible sur le serveur',
	'Attachments:Render:Icons' => 'Affichage en icônes',
	'Attachments:Render:Table' => 'Affichage en liste',
	'UI:Attachments:DropYourFileHint' => 'Déposez vos fichiers dans cet espace',
));

//
// Class: Attachment
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:Attachment' => 'Attachement',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Expire',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Id Temporaire',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Classe d\'Item',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Organisation de l\'Item',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Contenu',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('FR FR', 'French', 'Français', array(
	'Attachments:File:Thumbnail' => 'Icône',
	'Attachments:File:Name' => 'Nom du fichier',
	'Attachments:File:Date' => 'Date de chargement',
	'Attachments:File:Uploader' => 'Chargé par',
	'Attachments:File:Size' => 'Taille',
	'Attachments:File:MimeType' => 'Type',
	'Attachments:File:DownloadsCount' => 'Téléchargements',
));
//
// Class: Attachment
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:Attachment/Attribute:creation_date' => 'Date de création',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Utilisateur',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Contact',
	'Class:Attachment/Attribute:contact_id+' => '',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:TriggerOnAttachmentDownload' => 'Déclencheur sur le téléchargement d\'une pièce jointe d\'un objet',
	'Class:TriggerOnAttachmentDownload+' => '',
));
